Python: module TileStache.Goodies.Caches.GoogleCloud

TileStache.Goodies.Caches.GoogleCloud | index

`Caches tiles to Google Cloud Storage.
Requires boto (2.0+):
http://pypi.python.org/pypi/boto
Example configuration:
"cache": {
"name": "TileStache.Goodies.Caches.GoogleCloud:Cache",
"kwargs": {
"bucket": "<bucket name>",
"access": "<access key>",
"secret": "<secret key>"
}
}
cache parameters:
bucket
Required bucket name for GS. If it doesn't exist, it will be created.
access
Required access key ID for your GS account.
secret
Required secret access key for your GS account.`

Classes
`` |  | Cache
class Cache
`` |  | Methods defined here: __init__(self, bucket, access, secret) lock(self, layer, coord, format) `Acquire a cache lock for this tile. Returns nothing, but blocks until the lock has been acquired.` read(self, layer, coord, format) `Read a cached tile.` remove(self, layer, coord, format) `Remove a cached tile.` save(self, body, layer, coord, format) `Save a cached tile.` unlock(self, layer, coord, format) `Release a cache lock for this tile.`

Functions
`` |  | tile_key(layer, coord, format) `Return a tile key string.` time(...) `time() -> floating point number Return the current time in seconds since the Epoch. Fractions of a second may be present if the system clock provides them.`

Data
`` |  | GOOGLE_STORAGE = 'gs' LOCAL_FILE = 'file'